Struct parquet::record::List [−][src]
pub struct List { /* fields omitted */ }List represents a list which contains an array of elements.
Methods
impl List[src]
impl ListTrait Implementations
impl Clone for List[src]
impl Clone for Listfn clone(&self) -> List[src]
fn clone(&self) -> ListReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for List[src]
impl Debug for Listfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for List[src]
impl PartialEq for Listfn eq(&self, other: &List) -> bool[src]
fn eq(&self, other: &List) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &List) -> bool[src]
fn ne(&self, other: &List) -> boolThis method tests for !=.
impl ListAccessor for List[src]
impl ListAccessor for Listfn get_bool(&self, i: usize) -> Result<bool>[src]
fn get_bool(&self, i: usize) -> Result<bool>fn get_byte(&self, i: usize) -> Result<i8>[src]
fn get_byte(&self, i: usize) -> Result<i8>fn get_short(&self, i: usize) -> Result<i16>[src]
fn get_short(&self, i: usize) -> Result<i16>fn get_int(&self, i: usize) -> Result<i32>[src]
fn get_int(&self, i: usize) -> Result<i32>fn get_long(&self, i: usize) -> Result<i64>[src]
fn get_long(&self, i: usize) -> Result<i64>fn get_float(&self, i: usize) -> Result<f32>[src]
fn get_float(&self, i: usize) -> Result<f32>fn get_double(&self, i: usize) -> Result<f64>[src]
fn get_double(&self, i: usize) -> Result<f64>fn get_timestamp(&self, i: usize) -> Result<u64>[src]
fn get_timestamp(&self, i: usize) -> Result<u64>fn get_decimal(&self, i: usize) -> Result<&Decimal>[src]
fn get_decimal(&self, i: usize) -> Result<&Decimal>fn get_string(&self, i: usize) -> Result<&String>[src]
fn get_string(&self, i: usize) -> Result<&String>fn get_bytes(&self, i: usize) -> Result<&ByteArray>[src]
fn get_bytes(&self, i: usize) -> Result<&ByteArray>fn get_group(&self, i: usize) -> Result<&Row>[src]
fn get_group(&self, i: usize) -> Result<&Row>fn get_list(&self, i: usize) -> Result<&List>[src]
fn get_list(&self, i: usize) -> Result<&List>fn get_map(&self, i: usize) -> Result<&Map>[src]
fn get_map(&self, i: usize) -> Result<&Map>