Struct parquet::record::Map [−][src]
pub struct Map { /* fields omitted */ }Map represents a map which contains an list of key->value pairs.
Methods
impl Map[src]
impl MapTrait Implementations
impl Clone for Map[src]
impl Clone for Mapfn clone(&self) -> Map[src]
fn clone(&self) -> MapReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for Map[src]
impl Debug for Mapfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Map[src]
impl PartialEq for Mapfn eq(&self, other: &Map) -> bool[src]
fn eq(&self, other: &Map) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Map) -> bool[src]
fn ne(&self, other: &Map) -> boolThis method tests for !=.
impl MapAccessor for Map[src]
impl MapAccessor for Mapfn get_keys<'a>(&'a self) -> Box<ListAccessor + 'a>[src]
fn get_keys<'a>(&'a self) -> Box<ListAccessor + 'a>fn get_values<'a>(&'a self) -> Box<ListAccessor + 'a>[src]
fn get_values<'a>(&'a self) -> Box<ListAccessor + 'a>